"""
Python module generated from Java source file org.bukkit.event.entity.SpawnerSpawnEvent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import CreatureSpawner
from org.bukkit.entity import Entity
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class SpawnerSpawnEvent(EntitySpawnEvent):
    """
    Called when an entity is spawned into a world by a spawner.
    
    If a Spawner Spawn event is cancelled, the entity will not spawn.
    """

    def __init__(self, spawnee: "Entity", spawner: "CreatureSpawner"):
        ...


    def getSpawner(self) -> "CreatureSpawner":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.FaceAttachable

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data import *
from typing import Any, Callable, Iterable, Tuple


class FaceAttachable(BlockData):
    """
    'face' represents the face to which a lever or button is stuck.
    
    This is used in conjunction with Directional to compute the
    orientation of these blocks.
    """

    def getAttachedFace(self) -> "AttachedFace":
        """
        Gets the value of the 'face' property.

        Returns
        - the 'face' value
        """
        ...


    def setAttachedFace(self, face: "AttachedFace") -> None:
        """
        Sets the value of the 'face' property.

        Arguments
        - face: the new 'face' value
        """
        ...


    class AttachedFace(Enum):
        """
        The face to which a switch type block is stuck.
        """

        FLOOR = 0
        """
        The switch is mounted to the floor and pointing upwards.
        """
        WALL = 1
        """
        The switch is mounted to the wall.
        """
        CEILING = 2
        """
        The switch is mounted to the ceiling and pointing dowanrds.
        """



"""
Python module generated from Java source file org.bukkit.entity.SizedFireball

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class SizedFireball(Fireball):
    """
    Represents a sized fireball.
    """

    def getDisplayItem(self) -> "ItemStack":
        """
        Gets the display ItemStack.

        Returns
        - display ItemStack
        """
        ...


    def setDisplayItem(self, item: "ItemStack") -> None:
        """
        Sets the display ItemStack for the fireball.

        Arguments
        - item: the ItemStack to display
        """
        ...



"""
Python module generated from Java source file com.google.common.graph.Graphs

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.base import Objects
from com.google.common.collect import ImmutableSet
from com.google.common.collect import Iterables
from com.google.common.collect import Iterators
from com.google.common.collect import Maps
from com.google.common.graph import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Iterator
from java.util import Optional
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Graphs:
    """
    Static utility methods for Graph, ValueGraph, and Network instances.

    Author(s)
    - Joshua O'Madadhain

    Since
    - 20.0
    """

    @staticmethod
    def hasCycle(graph: "Graph"["N"]) -> bool:
        """
        Returns True if `graph` has at least one cycle. A cycle is defined as a non-empty subset
        of edges in a graph arranged to form a path (a sequence of adjacent outgoing edges) starting
        and ending with the same node.
        
        This method will detect any non-empty cycle, including self-loops (a cycle of length 1).
        """
        ...


    @staticmethod
    def hasCycle(network: "Network"[Any, Any]) -> bool:
        """
        Returns True if `network` has at least one cycle. A cycle is defined as a non-empty
        subset of edges in a graph arranged to form a path (a sequence of adjacent outgoing edges)
        starting and ending with the same node.
        
        This method will detect any non-empty cycle, including self-loops (a cycle of length 1).
        """
        ...


    @staticmethod
    def transitiveClosure(graph: "Graph"["N"]) -> "Graph"["N"]:
        ...


    @staticmethod
    def reachableNodes(graph: "Graph"["N"], node: "N") -> set["N"]:
        """
        Returns the set of nodes that are reachable from `node`. Node B is defined as reachable
        from node A if there exists a path (a sequence of adjacent outgoing edges) starting at node A
        and ending at node B. Note that a node is always reachable from itself via a zero-length path.
        
        This is a "snapshot" based on the current topology of `graph`, rather than a live view
        of the set of nodes reachable from `node`. In other words, the returned Set will
        not be updated after modifications to `graph`.

        Raises
        - IllegalArgumentException: if `node` is not present in `graph`
        """
        ...


    @staticmethod
    def transpose(graph: "Graph"["N"]) -> "Graph"["N"]:
        """
        Returns a view of `graph` with the direction (if any) of every edge reversed. All other
        properties remain intact, and further updates to `graph` will be reflected in the view.
        """
        ...


    @staticmethod
    def transpose(graph: "ValueGraph"["N", "V"]) -> "ValueGraph"["N", "V"]:
        """
        Returns a view of `graph` with the direction (if any) of every edge reversed. All other
        properties remain intact, and further updates to `graph` will be reflected in the view.
        """
        ...


    @staticmethod
    def transpose(network: "Network"["N", "E"]) -> "Network"["N", "E"]:
        """
        Returns a view of `network` with the direction (if any) of every edge reversed. All other
        properties remain intact, and further updates to `network` will be reflected in the view.
        """
        ...


    @staticmethod
    def inducedSubgraph(graph: "Graph"["N"], nodes: Iterable["N"]) -> "MutableGraph"["N"]:
        """
        Returns the subgraph of `graph` induced by `nodes`. This subgraph is a new graph
        that contains all of the nodes in `nodes`, and all of the Graph.edges() edges
        from `graph` for which both nodes are contained by `nodes`.

        Raises
        - IllegalArgumentException: if any element in `nodes` is not a node in the graph
        """
        ...


    @staticmethod
    def inducedSubgraph(graph: "ValueGraph"["N", "V"], nodes: Iterable["N"]) -> "MutableValueGraph"["N", "V"]:
        """
        Returns the subgraph of `graph` induced by `nodes`. This subgraph is a new graph
        that contains all of the nodes in `nodes`, and all of the Graph.edges() edges
        (and associated edge values) from `graph` for which both nodes are contained by `nodes`.

        Raises
        - IllegalArgumentException: if any element in `nodes` is not a node in the graph
        """
        ...


    @staticmethod
    def inducedSubgraph(network: "Network"["N", "E"], nodes: Iterable["N"]) -> "MutableNetwork"["N", "E"]:
        """
        Returns the subgraph of `network` induced by `nodes`. This subgraph is a new graph
        that contains all of the nodes in `nodes`, and all of the Network.edges() edges
        from `network` for which the Network.incidentNodes(Object) incident nodes are
        both contained by `nodes`.

        Raises
        - IllegalArgumentException: if any element in `nodes` is not a node in the graph
        """
        ...


    @staticmethod
    def copyOf(graph: "Graph"["N"]) -> "MutableGraph"["N"]:
        """
        Creates a mutable copy of `graph` with the same nodes and edges.
        """
        ...


    @staticmethod
    def copyOf(graph: "ValueGraph"["N", "V"]) -> "MutableValueGraph"["N", "V"]:
        """
        Creates a mutable copy of `graph` with the same nodes, edges, and edge values.
        """
        ...


    @staticmethod
    def copyOf(network: "Network"["N", "E"]) -> "MutableNetwork"["N", "E"]:
        """
        Creates a mutable copy of `network` with the same nodes and edges.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerDropItemEvent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Item
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerDropItemEvent(PlayerEvent, Cancellable):
    """
    Thrown when a player drops an item from their inventory
    """

    def __init__(self, player: "Player", drop: "Item"):
        ...


    def getItemDrop(self) -> "Item":
        """
        Gets the ItemDrop created by the player

        Returns
        - ItemDrop created by the player
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.CollectionFuture

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import ImmutableCollection
from com.google.common.collect import Lists
from com.google.common.util.concurrent import *
from java.util import Collections
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class CollectionFuture(AggregateFuture):
    """
    Aggregate future that collects (stores) results of each future.
    """





"""
Python module generated from Java source file org.bukkit.plugin.ServicePriority

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class ServicePriority(Enum):
    """
    Represents various priorities of a provider.
    """

    Lowest = 0
    Low = 1
    Normal = 2
    High = 3
    Highest = 4



"""
Python module generated from Java source file org.bukkit.enchantments.Enchantment

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import Lists
from java.util import Locale
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit import Translatable
from org.bukkit.enchantments import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class Enchantment(Keyed, Translatable):
    """
    The various type of enchantments that may be added to armour or weapons
    """

    PROTECTION = getEnchantment("protection")
    """
    Provides protection against environmental damage
    """
    FIRE_PROTECTION = getEnchantment("fire_protection")
    """
    Provides protection against fire damage
    """
    FEATHER_FALLING = getEnchantment("feather_falling")
    """
    Provides protection against fall damage
    """
    BLAST_PROTECTION = getEnchantment("blast_protection")
    """
    Provides protection against explosive damage
    """
    PROJECTILE_PROTECTION = getEnchantment("projectile_protection")
    """
    Provides protection against projectile damage
    """
    RESPIRATION = getEnchantment("respiration")
    """
    Decreases the rate of air loss whilst underwater
    """
    AQUA_AFFINITY = getEnchantment("aqua_affinity")
    """
    Increases the speed at which a player may mine underwater
    """
    THORNS = getEnchantment("thorns")
    """
    Damages the attacker
    """
    DEPTH_STRIDER = getEnchantment("depth_strider")
    """
    Increases walking speed while in water
    """
    FROST_WALKER = getEnchantment("frost_walker")
    """
    Freezes any still water adjacent to ice / frost which player is walking on
    """
    BINDING_CURSE = getEnchantment("binding_curse")
    """
    Item cannot be removed
    """
    SHARPNESS = getEnchantment("sharpness")
    """
    Increases damage against all targets
    """
    SMITE = getEnchantment("smite")
    """
    Increases damage against undead targets
    """
    BANE_OF_ARTHROPODS = getEnchantment("bane_of_arthropods")
    """
    Increases damage against arthropod targets
    """
    KNOCKBACK = getEnchantment("knockback")
    """
    All damage to other targets will knock them back when hit
    """
    FIRE_ASPECT = getEnchantment("fire_aspect")
    """
    When attacking a target, has a chance to set them on fire
    """
    LOOTING = getEnchantment("looting")
    """
    Provides a chance of gaining extra loot when killing monsters
    """
    SWEEPING_EDGE = getEnchantment("sweeping_edge")
    """
    Increases damage against targets when using a sweep attack
    """
    EFFICIENCY = getEnchantment("efficiency")
    """
    Increases the rate at which you mine/dig
    """
    SILK_TOUCH = getEnchantment("silk_touch")
    """
    Allows blocks to drop themselves instead of fragments (for example,
    stone instead of cobblestone)
    """
    UNBREAKING = getEnchantment("unbreaking")
    """
    Decreases the rate at which a tool looses durability
    """
    FORTUNE = getEnchantment("fortune")
    """
    Provides a chance of gaining extra loot when destroying blocks
    """
    POWER = getEnchantment("power")
    """
    Provides extra damage when shooting arrows from bows
    """
    PUNCH = getEnchantment("punch")
    """
    Provides a knockback when an entity is hit by an arrow from a bow
    """
    FLAME = getEnchantment("flame")
    """
    Sets entities on fire when hit by arrows shot from a bow
    """
    INFINITY = getEnchantment("infinity")
    """
    Provides infinite arrows when shooting a bow
    """
    LUCK_OF_THE_SEA = getEnchantment("luck_of_the_sea")
    """
    Decreases odds of catching worthless junk
    """
    LURE = getEnchantment("lure")
    """
    Increases rate of fish biting your hook
    """
    LOYALTY = getEnchantment("loyalty")
    """
    Causes a thrown trident to return to the player who threw it
    """
    IMPALING = getEnchantment("impaling")
    """
    Deals more damage to mobs that live in the ocean
    """
    RIPTIDE = getEnchantment("riptide")
    """
    When it is rainy, launches the player in the direction their trident is thrown
    """
    CHANNELING = getEnchantment("channeling")
    """
    Strikes lightning when a mob is hit with a trident if conditions are
    stormy
    """
    MULTISHOT = getEnchantment("multishot")
    """
    Shoot multiple arrows from crossbows
    """
    QUICK_CHARGE = getEnchantment("quick_charge")
    """
    Charges crossbows quickly
    """
    PIERCING = getEnchantment("piercing")
    """
    Crossbow projectiles pierce entities
    """
    DENSITY = getEnchantment("density")
    """
    Increases fall damage of maces
    """
    BREACH = getEnchantment("breach")
    """
    Reduces armor effectiveness against maces
    """
    WIND_BURST = getEnchantment("wind_burst")
    """
    Emits wind burst upon hitting enemy
    """
    MENDING = getEnchantment("mending")
    """
    Allows mending the item using experience orbs
    """
    VANISHING_CURSE = getEnchantment("vanishing_curse")
    """
    Item disappears instead of dropping
    """
    SOUL_SPEED = getEnchantment("soul_speed")
    """
    Walk quicker on soul blocks
    """
    SWIFT_SNEAK = getEnchantment("swift_sneak")
    """
    Walk quicker while sneaking
    """


    def getName(self) -> str:
        """
        Gets the unique name of this enchantment

        Returns
        - Unique name

        Deprecated
        - enchantments are badly named, use .getKey().
        """
        ...


    def getMaxLevel(self) -> int:
        """
        Gets the maximum level that this Enchantment may become.

        Returns
        - Maximum level of the Enchantment
        """
        ...


    def getStartLevel(self) -> int:
        """
        Gets the level that this Enchantment should start at

        Returns
        - Starting level of the Enchantment
        """
        ...


    def getItemTarget(self) -> "EnchantmentTarget":
        """
        Gets the type of ItemStack that may fit this Enchantment.

        Returns
        - Target type of the Enchantment

        Deprecated
        - enchantment groupings are now managed by tags, not categories
        """
        ...


    def isTreasure(self) -> bool:
        """
        Checks if this enchantment is a treasure enchantment.
        
        Treasure enchantments can only be received via looting, trading, or
        fishing.

        Returns
        - True if the enchantment is a treasure enchantment

        Deprecated
        - enchantment types are now managed by tags
        """
        ...


    def isCursed(self) -> bool:
        """
        Checks if this enchantment is a cursed enchantment
        
        Cursed enchantments are found the same way treasure enchantments are

        Returns
        - True if the enchantment is cursed

        Deprecated
        - cursed enchantments are no longer special. Will return True
        only for Enchantment.BINDING_CURSE and
        Enchantment.VANISHING_CURSE.
        """
        ...


    def conflictsWith(self, other: "Enchantment") -> bool:
        """
        Check if this enchantment conflicts with another enchantment.

        Arguments
        - other: The enchantment to check against

        Returns
        - True if there is a conflict.
        """
        ...


    def canEnchantItem(self, item: "ItemStack") -> bool:
        """
        Checks if this Enchantment may be applied to the given ItemStack.
        
        This does not check if it conflicts with any enchantments already
        applied to the item.

        Arguments
        - item: Item to test

        Returns
        - True if the enchantment may be applied, otherwise False
        """
        ...


    @staticmethod
    def getByKey(key: "NamespacedKey") -> "Enchantment":
        """
        Gets the Enchantment at the specified key

        Arguments
        - key: key to fetch

        Returns
        - Resulting Enchantment, or null if not found

        Deprecated
        - only for backwards compatibility, use Registry.get(NamespacedKey) instead
        """
        ...


    @staticmethod
    def getByName(name: str) -> "Enchantment":
        """
        Gets the Enchantment at the specified name

        Arguments
        - name: Name to fetch

        Returns
        - Resulting Enchantment, or null if not found

        Deprecated
        - enchantments are badly named, use .getByKey(org.bukkit.NamespacedKey).
        """
        ...


    @staticmethod
    def values() -> list["Enchantment"]:
        """
        Gets an array of all the registered Enchantments

        Returns
        - Array of enchantments

        Deprecated
        - use Registry.iterator() Registry.ENCHANTMENT.iterator()
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.CartographyInventory

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class CartographyInventory(Inventory):
    """
    Interface to the inventory of a Cartography table.
    """





"""
Python module generated from Java source file com.google.common.util.concurrent.AtomicDouble

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.j2objc.annotations import ReflectionSupport
from java.util.concurrent.atomic import AtomicLongFieldUpdater
from java.util.function import DoubleBinaryOperator
from java.util.function import DoubleUnaryOperator
from typing import Any, Callable, Iterable, Tuple


class AtomicDouble(Number, Serializable):
    """
    A `double` value that may be updated atomically. See the java.util.concurrent.atomic package specification for description of the properties of atomic
    variables. An `AtomicDouble` is used in applications such as atomic accumulation, and
    cannot be used as a replacement for a Double. However, this class does extend `Number` to allow uniform access by tools and utilities that deal with numerically-based classes.
    
    <a id="bitEquals"></a>This class compares primitive `double` values in methods such as
    .compareAndSet by comparing their bitwise representation using Double.doubleToRawLongBits, which differs from both the primitive double `==` operator and
    from Double.equals, as if implemented by:
    
    ````static boolean bitEquals(double x, double y) {
      long xBits = Double.doubleToRawLongBits(x);
      long yBits = Double.doubleToRawLongBits(y);
      return xBits == yBits;`
    }```
    
    It is possible to write a more scalable updater, at the cost of giving up strict atomicity.
    See for example <a
    href="http://gee.cs.oswego.edu/dl/jsr166/dist/docs/java.base/java/util/concurrent/atomic/DoubleAdder.html">
    DoubleAdder</a>.

    Author(s)
    - Martin Buchholz

    Since
    - 11.0
    """

    def __init__(self, initialValue: float):
        """
        Creates a new `AtomicDouble` with the given initial value.

        Arguments
        - initialValue: the initial value
        """
        ...


    def __init__(self):
        """
        Creates a new `AtomicDouble` with initial value `0.0`.
        """
        ...


    def get(self) -> float:
        """
        Gets the current value.

        Returns
        - the current value
        """
        ...


    def set(self, newValue: float) -> None:
        """
        Sets to the given value.

        Arguments
        - newValue: the new value
        """
        ...


    def lazySet(self, newValue: float) -> None:
        """
        Eventually sets to the given value.

        Arguments
        - newValue: the new value
        """
        ...


    def getAndSet(self, newValue: float) -> float:
        """
        Atomically sets to the given value and returns the old value.

        Arguments
        - newValue: the new value

        Returns
        - the previous value
        """
        ...


    def compareAndSet(self, expect: float, update: float) -> bool:
        """
        Atomically sets the value to the given updated value if the current value is <a
        href="#bitEquals">bitwise equal</a> to the expected value.

        Arguments
        - expect: the expected value
        - update: the new value

        Returns
        - `True` if successful. False return indicates that the actual value was not
            bitwise equal to the expected value.
        """
        ...


    def weakCompareAndSet(self, expect: float, update: float) -> bool:
        """
        Atomically sets the value to the given updated value if the current value is <a
        href="#bitEquals">bitwise equal</a> to the expected value.
        
        May <a
        href="http://download.oracle.com/javase/7/docs/api/java/util/concurrent/atomic/package-summary.html#Spurious">
        fail spuriously</a> and does not provide ordering guarantees, so is only rarely an appropriate
        alternative to `compareAndSet`.

        Arguments
        - expect: the expected value
        - update: the new value

        Returns
        - `True` if successful
        """
        ...


    def getAndAdd(self, delta: float) -> float:
        """
        Atomically adds the given value to the current value.

        Arguments
        - delta: the value to add

        Returns
        - the previous value
        """
        ...


    def addAndGet(self, delta: float) -> float:
        """
        Atomically adds the given value to the current value.

        Arguments
        - delta: the value to add

        Returns
        - the updated value
        """
        ...


    def getAndAccumulate(self, x: float, accumulatorFunction: "DoubleBinaryOperator") -> float:
        """
        Atomically updates the current value with the results of applying the given function to the
        current and given values.

        Arguments
        - x: the update value
        - accumulatorFunction: the accumulator function

        Returns
        - the previous value

        Since
        - 31.1
        """
        ...


    def accumulateAndGet(self, x: float, accumulatorFunction: "DoubleBinaryOperator") -> float:
        """
        Atomically updates the current value with the results of applying the given function to the
        current and given values.

        Arguments
        - x: the update value
        - accumulatorFunction: the accumulator function

        Returns
        - the updated value

        Since
        - 31.1
        """
        ...


    def getAndUpdate(self, updateFunction: "DoubleUnaryOperator") -> float:
        """
        Atomically updates the current value with the results of applying the given function.

        Arguments
        - updateFunction: the update function

        Returns
        - the previous value

        Since
        - 31.1
        """
        ...


    def updateAndGet(self, updateFunction: "DoubleUnaryOperator") -> float:
        """
        Atomically updates the current value with the results of applying the given function.

        Arguments
        - updateFunction: the update function

        Returns
        - the updated value

        Since
        - 31.1
        """
        ...


    def toString(self) -> str:
        """
        Returns the String representation of the current value.

        Returns
        - the String representation of the current value
        """
        ...


    def intValue(self) -> int:
        """
        Returns the value of this `AtomicDouble` as an `int` after a narrowing primitive
        conversion.
        """
        ...


    def longValue(self) -> int:
        """
        Returns the value of this `AtomicDouble` as a `long` after a narrowing primitive
        conversion.
        """
        ...


    def floatValue(self) -> float:
        """
        Returns the value of this `AtomicDouble` as a `float` after a narrowing primitive
        conversion.
        """
        ...


    def doubleValue(self) -> float:
        """
        Returns the value of this `AtomicDouble` as a `double`.
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.CommandBlock

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Directional
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class CommandBlock(Directional):
    """
    'conditional' denotes whether this command block is conditional or not, i.e.
    will only execute if the preceeding command block also executed successfully.
    """

    def isConditional(self) -> bool:
        """
        Gets the value of the 'conditional' property.

        Returns
        - the 'conditional' value
        """
        ...


    def setConditional(self, conditional: bool) -> None:
        """
        Sets the value of the 'conditional' property.

        Arguments
        - conditional: the new 'conditional' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.Rotatable

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import BlockFace
from org.bukkit.block.data import *
from typing import Any, Callable, Iterable, Tuple


class Rotatable(BlockData):
    """
    'rotation' represents the current rotation of this block.
    """

    def getRotation(self) -> "BlockFace":
        """
        Gets the value of the 'rotation' property.

        Returns
        - the 'rotation' value
        """
        ...


    def setRotation(self, rotation: "BlockFace") -> None:
        """
        Sets the value of the 'rotation' property.

        Arguments
        - rotation: the new 'rotation' value
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.Hashing

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.common.primitives import Ints
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Hashing:
    """
    Static methods for implementing hash-based collections.

    Author(s)
    - Austin Appleby
    """





"""
Python module generated from Java source file com.google.common.collect.FilteredKeyListMultimap

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Predicate
from com.google.common.collect import *
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class FilteredKeyListMultimap(FilteredKeyMultimap, ListMultimap):
    """
    Implementation of Multimaps.filterKeys(ListMultimap, Predicate).

    Author(s)
    - Louis Wasserman
    """

    def unfiltered(self) -> "ListMultimap"["K", "V"]:
        ...


    def get(self, key: "K") -> list["V"]:
        ...


    def removeAll(self, key: "Object") -> list["V"]:
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> list["V"]:
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableBiMapFauxverideShim

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import DoNotCall
from java.util.function import BinaryOperator
from java.util.function import Function
from java.util.stream import Collector
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ImmutableBiMapFauxverideShim(ImmutableMap):
    """
    "Overrides" the ImmutableMap static methods that lack ImmutableBiMap equivalents
    with deprecated, exception-throwing versions. See ImmutableSortedSetFauxverideShim for
    details.

    Author(s)
    - Louis Wasserman
    """

    @staticmethod
    def toImmutableMap(keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"]) -> "Collector"["T", Any, "ImmutableMap"["K", "V"]]:
        """
        Not supported. Use ImmutableBiMap.toImmutableBiMap instead. This method exists only to
        hide ImmutableMap.toImmutableMap(Function, Function) from consumers of `ImmutableBiMap`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - Use ImmutableBiMap.toImmutableBiMap.
        """
        ...


    @staticmethod
    def toImmutableMap(keyFunction: "Function"["T", "K"], valueFunction: "Function"["T", "V"], mergeFunction: "BinaryOperator"["V"]) -> "Collector"["T", Any, "ImmutableMap"["K", "V"]]:
        """
        Not supported. This method does not make sense for `BiMap`. This method exists only to
        hide ImmutableMap.toImmutableMap(Function, Function, BinaryOperator) from consumers of
        `ImmutableBiMap`.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - 
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.vehicle.VehicleBlockCollisionEvent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.entity import Vehicle
from org.bukkit.event import HandlerList
from org.bukkit.event.vehicle import *
from typing import Any, Callable, Iterable, Tuple


class VehicleBlockCollisionEvent(VehicleCollisionEvent):
    """
    Raised when a vehicle collides with a block.
    """

    def __init__(self, vehicle: "Vehicle", block: "Block"):
        ...


    def getBlock(self) -> "Block":
        """
        Gets the block the vehicle collided with

        Returns
        - the block the vehicle collided with
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.InterruptibleTask

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.util.concurrent import *
from com.google.j2objc.annotations import ReflectionSupport
from java.util.concurrent.atomic import AtomicReference
from java.util.concurrent.locks import AbstractOwnableSynchronizer
from java.util.concurrent.locks import LockSupport
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class InterruptibleTask(AtomicReference, Runnable):

    def run(self) -> None:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.util.BiomeSearchResult

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit import World
from org.bukkit.block import Biome
from org.bukkit.util import *
from typing import Any, Callable, Iterable, Tuple


class BiomeSearchResult:
    """
    Holds the result of searching for a biome.

    See
    - World.locateNearestBiome(Location, int, int, int, Biome...)
    """

    def getBiome(self) -> "Biome":
        """
        Return the biome which was found.

        Returns
        - the found biome.
        """
        ...


    def getLocation(self) -> "Location":
        """
        Return the location of the biome.

        Returns
        - the location the biome was found.
        """
        ...



"""
Python module generated from Java source file com.google.gson.ReflectionAccessFilter

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.internal import ReflectionAccessFilterHelper
from java.lang.reflect import AccessibleObject
from typing import Any, Callable, Iterable, Tuple


class ReflectionAccessFilter:
    """
    Filter for determining whether reflection based serialization and
    deserialization is allowed for a class.
    
    A filter can be useful in multiple scenarios, for example when
    upgrading to newer Java versions which use the Java Platform Module
    System (JPMS). A filter then allows to FilterResult.BLOCK_INACCESSIBLE
    prevent making inaccessible members accessible, even if the used
    Java version might still allow illegal access (but logs a warning),
    or if `java` command line arguments are used to open the inaccessible
    packages to other parts of the application. This interface defines some
    convenience filters for this task, such as .BLOCK_INACCESSIBLE_JAVA.
    
    A filter can also be useful to prevent mixing model classes of a
    project with other non-model classes; the filter could
    FilterResult.BLOCK_ALL block all reflective access to
    non-model classes.
    
    A reflection access filter is similar to an ExclusionStrategy
    with the major difference that a filter will cause an exception to be
    thrown when access is disallowed while an exclusion strategy just skips
    fields and classes.

    See
    - GsonBuilder.addReflectionAccessFilter(ReflectionAccessFilter)

    Since
    - 2.9.1
    """

    BLOCK_INACCESSIBLE_JAVA = ReflectionAccessFilter() {
    
        @Override
        public FilterResult check(Class<?> rawClass) {
            return ReflectionAccessFilterHelper.isJavaType(rawClass) ? FilterResult.BLOCK_INACCESSIBLE : FilterResult.INDECISIVE;
        }
    }
    """
    Blocks all reflection access to members of standard Java classes which are
    not accessible by default. However, reflection access is still allowed for
    classes for which all fields are accessible and which have an accessible
    no-args constructor (or for which an InstanceCreator has been registered).
    
    If this filter encounters a class other than a standard Java class it
    returns FilterResult.INDECISIVE.
    
    This filter is mainly intended to help enforcing the access checks of
    Java Platform Module System. It allows detecting illegal access, even if
    the used Java version would only log a warning, or is configured to open
    packages for reflection. However, this filter **only works for Java 9 and
    higher**, when using an older Java version its functionality will be
    limited.
    
    Note that this filter might not cover all standard Java classes. Currently
    only classes in a `java.*` or `javax.*` package are considered. The
    set of detected classes might be expanded in the future without prior notice.

    See
    - FilterResult.BLOCK_INACCESSIBLE
    """
    BLOCK_ALL_JAVA = ReflectionAccessFilter() {
    
        @Override
        public FilterResult check(Class<?> rawClass) {
            return ReflectionAccessFilterHelper.isJavaType(rawClass) ? FilterResult.BLOCK_ALL : FilterResult.INDECISIVE;
        }
    }
    """
    Blocks all reflection access to members of standard Java classes.
    
    If this filter encounters a class other than a standard Java class it
    returns FilterResult.INDECISIVE.
    
    This filter is mainly intended to prevent depending on implementation
    details of the Java platform and to help applications prepare for upgrading
    to the Java Platform Module System.
    
    Note that this filter might not cover all standard Java classes. Currently
    only classes in a `java.*` or `javax.*` package are considered. The
    set of detected classes might be expanded in the future without prior notice.

    See
    - FilterResult.BLOCK_ALL
    """
    BLOCK_ALL_ANDROID = ReflectionAccessFilter() {
    
        @Override
        public FilterResult check(Class<?> rawClass) {
            return ReflectionAccessFilterHelper.isAndroidType(rawClass) ? FilterResult.BLOCK_ALL : FilterResult.INDECISIVE;
        }
    }
    """
    Blocks all reflection access to members of standard Android classes.
    
    If this filter encounters a class other than a standard Android class it
    returns FilterResult.INDECISIVE.
    
    This filter is mainly intended to prevent depending on implementation
    details of the Android platform.
    
    Note that this filter might not cover all standard Android classes. Currently
    only classes in an `android.*` or `androidx.*` package, and standard
    Java classes in a `java.*` or `javax.*` package are considered. The
    set of detected classes might be expanded in the future without prior notice.

    See
    - FilterResult.BLOCK_ALL
    """
    BLOCK_ALL_PLATFORM = ReflectionAccessFilter() {
    
        @Override
        public FilterResult check(Class<?> rawClass) {
            return ReflectionAccessFilterHelper.isAnyPlatformType(rawClass) ? FilterResult.BLOCK_ALL : FilterResult.INDECISIVE;
        }
    }
    """
    Blocks all reflection access to members of classes belonging to programming
    language platforms, such as Java, Android, Kotlin or Scala.
    
    If this filter encounters a class other than a standard platform class it
    returns FilterResult.INDECISIVE.
    
    This filter is mainly intended to prevent depending on implementation
    details of the platform classes.
    
    Note that this filter might not cover all platform classes. Currently it
    combines the filters .BLOCK_ALL_JAVA and .BLOCK_ALL_ANDROID,
    and checks for other language-specific platform classes like `kotlin.*`.
    The set of detected classes might be expanded in the future without prior notice.

    See
    - FilterResult.BLOCK_ALL
    """


    def check(self, rawClass: type[Any]) -> "FilterResult":
        """
        Checks if reflection access should be allowed for a class.

        Arguments
        - rawClass: Class to check

        Returns
        - Result indicating whether reflection access is allowed
        """
        ...



"""
Python module generated from Java source file com.google.gson.ToNumberPolicy

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.internal import LazilyParsedNumber
from com.google.gson.stream import JsonReader
from com.google.gson.stream import MalformedJsonException
from enum import Enum
from java.io import IOException
from java.math import BigDecimal
from typing import Any, Callable, Iterable, Tuple


class ToNumberPolicy(Enum):
    """
    An enumeration that defines two standard number reading strategies and a couple of
    strategies to overcome some historical Gson limitations while deserializing numbers as
    Object and Number.

    See
    - ToNumberStrategy

    Since
    - 2.8.9
    """

    DOUBLE = 0
    """
    Using this policy will ensure that numbers will be read as Double values.
    This is the default strategy used during deserialization of numbers as Object.
    """
    LAZILY_PARSED_NUMBER = 1
    """
    Using this policy will ensure that numbers will be read as a lazily parsed number backed
    by a string. This is the default strategy used during deserialization of numbers as
    Number.
    """
    LONG_OR_DOUBLE = 2
    """
    Using this policy will ensure that numbers will be read as Long or Double
    values depending on how JSON numbers are represented: `Long` if the JSON number can
    be parsed as a `Long` value, or otherwise `Double` if it can be parsed as a
    `Double` value. If the parsed double-precision number results in a positive or negative
    infinity (Double.isInfinite()) or a NaN (Double.isNaN()) value and the
    `JsonReader` is not JsonReader.isLenient() lenient, a MalformedJsonException
    is thrown.
    """
    BIG_DECIMAL = 3
    """
    Using this policy will ensure that numbers will be read as numbers of arbitrary length
    using BigDecimal.
    """



"""
Python module generated from Java source file org.bukkit.WeatherType

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class WeatherType(Enum):
    """
    An enum of all current weather types
    """

    DOWNFALL = 0
    """
    Raining or snowing depending on biome.
    """
    CLEAR = 1
    """
    Clear weather, clouds but no rain.
    """



"""
Python module generated from Java source file org.bukkit.entity.Phantom

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Phantom(Flying, Enemy):
    """
    Represents a phantom.
    """

    def getSize(self) -> int:
        """
        Returns
        - The size of the phantom
        """
        ...


    def setSize(self, sz: int) -> None:
        """
        Arguments
        - sz: The new size of the phantom.
        """
        ...



"""
Python module generated from Java source file org.bukkit.conversations.RegexPrompt

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.regex import Pattern
from org.bukkit.conversations import *
from typing import Any, Callable, Iterable, Tuple


class RegexPrompt(ValidatingPrompt):
    """
    RegexPrompt is the base class for any prompt that requires an input
    validated by a regular expression.
    """

    def __init__(self, regex: str):
        ...


    def __init__(self, pattern: "Pattern"):
        ...



"""
Python module generated from Java source file org.bukkit.entity.ComplexLivingEntity

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class ComplexLivingEntity(LivingEntity):
    """
    Represents a complex living entity - one that is made up of various smaller
    parts
    """

    def getParts(self) -> set["ComplexEntityPart"]:
        """
        Gets a list of parts that belong to this complex entity

        Returns
        - List of parts
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Villager

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import Lists
from java.util import Locale
from org.bukkit import Keyed
from org.bukkit import Location
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit.entity import *
from org.bukkit.util import OldEnum
from typing import Any, Callable, Iterable, Tuple


class Villager(AbstractVillager):
    """
    Represents a villager NPC
    """

    def getProfession(self) -> "Profession":
        """
        Gets the current profession of this villager.

        Returns
        - Current profession.
        """
        ...


    def setProfession(self, profession: "Profession") -> None:
        """
        Sets the new profession of this villager.

        Arguments
        - profession: New profession.
        """
        ...


    def getVillagerType(self) -> "Type":
        """
        Gets the current type of this villager.

        Returns
        - Current type.
        """
        ...


    def setVillagerType(self, type: "Type") -> None:
        """
        Sets the new type of this villager.

        Arguments
        - type: New type.
        """
        ...


    def getVillagerLevel(self) -> int:
        """
        Gets the level of this villager.
        
        A villager with a level of 1 and no experience is liable to lose its
        profession.

        Returns
        - this villager's level
        """
        ...


    def setVillagerLevel(self, level: int) -> None:
        """
        Sets the level of this villager.
        
        A villager with a level of 1 and no experience is liable to lose its
        profession.

        Arguments
        - level: the new level

        Raises
        - IllegalArgumentException: if level not between [1, 5]
        """
        ...


    def getVillagerExperience(self) -> int:
        """
        Gets the trading experience of this villager.

        Returns
        - trading experience
        """
        ...


    def setVillagerExperience(self, experience: int) -> None:
        """
        Sets the trading experience of this villager.

        Arguments
        - experience: new experience

        Raises
        - IllegalArgumentException: if experience &lt; 0
        """
        ...


    def sleep(self, location: "Location") -> bool:
        """
        Attempts to make this villager sleep at the given location.
        
        The location must be in the current world and have a bed placed at the
        location. The villager will put its head on the specified block while
        sleeping.

        Arguments
        - location: the location of the bed

        Returns
        - whether the sleep was successful
        """
        ...


    def wakeup(self) -> None:
        """
        Causes this villager to wake up if he's currently sleeping.

        Raises
        - IllegalStateException: if not sleeping
        """
        ...


    def shakeHead(self) -> None:
        """
        Causes this villager to shake his head.
        """
        ...


    def zombify(self) -> "ZombieVillager":
        """
        Convert this Villager into a ZombieVillager as if it was killed by a
        Zombie.
        
        **Note:** this will fire a EntityTransformEvent

        Returns
        - the converted entity ZombieVillager or null if the
        conversion its cancelled
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.AtomicDoubleArray

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.primitives import ImmutableLongArray
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util.concurrent.atomic import AtomicLongArray
from java.util.function import DoubleBinaryOperator
from java.util.function import DoubleUnaryOperator
from typing import Any, Callable, Iterable, Tuple


class AtomicDoubleArray(Serializable):
    """
    A `double` array in which elements may be updated atomically. See the java.util.concurrent.atomic package specification for description of the properties of atomic
    variables.
    
    <a id="bitEquals"></a>This class compares primitive `double` values in methods such as
    .compareAndSet by comparing their bitwise representation using Double.doubleToRawLongBits, which differs from both the primitive double `==` operator and
    from Double.equals, as if implemented by:
    
    ````static boolean bitEquals(double x, double y) {
      long xBits = Double.doubleToRawLongBits(x);
      long yBits = Double.doubleToRawLongBits(y);
      return xBits == yBits;`
    }```

    Author(s)
    - Martin Buchholz

    Since
    - 11.0
    """

    def __init__(self, length: int):
        """
        Creates a new `AtomicDoubleArray` of the given length, with all elements initially zero.

        Arguments
        - length: the length of the array
        """
        ...


    def __init__(self, array: list[float]):
        """
        Creates a new `AtomicDoubleArray` with the same length as, and all elements copied from,
        the given array.

        Arguments
        - array: the array to copy elements from

        Raises
        - NullPointerException: if array is null
        """
        ...


    def length(self) -> int:
        """
        Returns the length of the array.

        Returns
        - the length of the array
        """
        ...


    def get(self, i: int) -> float:
        """
        Gets the current value at position `i`.

        Arguments
        - i: the index

        Returns
        - the current value
        """
        ...


    def set(self, i: int, newValue: float) -> None:
        """
        Atomically sets the element at position `i` to the given value.

        Arguments
        - i: the index
        - newValue: the new value
        """
        ...


    def lazySet(self, i: int, newValue: float) -> None:
        """
        Eventually sets the element at position `i` to the given value.

        Arguments
        - i: the index
        - newValue: the new value
        """
        ...


    def getAndSet(self, i: int, newValue: float) -> float:
        """
        Atomically sets the element at position `i` to the given value and returns the old value.

        Arguments
        - i: the index
        - newValue: the new value

        Returns
        - the previous value
        """
        ...


    def compareAndSet(self, i: int, expect: float, update: float) -> bool:
        """
        Atomically sets the element at position `i` to the given updated value if the current
        value is <a href="#bitEquals">bitwise equal</a> to the expected value.

        Arguments
        - i: the index
        - expect: the expected value
        - update: the new value

        Returns
        - True if successful. False return indicates that the actual value was not equal to the
            expected value.
        """
        ...


    def weakCompareAndSet(self, i: int, expect: float, update: float) -> bool:
        """
        Atomically sets the element at position `i` to the given updated value if the current
        value is <a href="#bitEquals">bitwise equal</a> to the expected value.
        
        May <a
        href="http://download.oracle.com/javase/7/docs/api/java/util/concurrent/atomic/package-summary.html#Spurious">
        fail spuriously</a> and does not provide ordering guarantees, so is only rarely an appropriate
        alternative to `compareAndSet`.

        Arguments
        - i: the index
        - expect: the expected value
        - update: the new value

        Returns
        - True if successful
        """
        ...


    def getAndAdd(self, i: int, delta: float) -> float:
        """
        Atomically adds the given value to the element at index `i`.

        Arguments
        - i: the index
        - delta: the value to add

        Returns
        - the previous value
        """
        ...


    def addAndGet(self, i: int, delta: float) -> float:
        """
        Atomically adds the given value to the element at index `i`.

        Arguments
        - i: the index
        - delta: the value to add

        Returns
        - the updated value
        """
        ...


    def getAndAccumulate(self, i: int, x: float, accumulatorFunction: "DoubleBinaryOperator") -> float:
        """
        Atomically updates the element at index `i` with the results of applying the given
        function to the current and given values.

        Arguments
        - i: the index to update
        - x: the update value
        - accumulatorFunction: the accumulator function

        Returns
        - the previous value

        Since
        - 31.1
        """
        ...


    def accumulateAndGet(self, i: int, x: float, accumulatorFunction: "DoubleBinaryOperator") -> float:
        """
        Atomically updates the element at index `i` with the results of applying the given
        function to the current and given values.

        Arguments
        - i: the index to update
        - x: the update value
        - accumulatorFunction: the accumulator function

        Returns
        - the updated value

        Since
        - 31.1
        """
        ...


    def getAndUpdate(self, i: int, updaterFunction: "DoubleUnaryOperator") -> float:
        """
        Atomically updates the element at index `i` with the results of applying the given
        function to the current value.

        Arguments
        - i: the index to update
        - updaterFunction: the update function

        Returns
        - the previous value

        Since
        - 31.1
        """
        ...


    def updateAndGet(self, i: int, updaterFunction: "DoubleUnaryOperator") -> float:
        """
        Atomically updates the element at index `i` with the results of applying the given
        function to the current value.

        Arguments
        - i: the index to update
        - updaterFunction: the update function

        Returns
        - the updated value

        Since
        - 31.1
        """
        ...


    def toString(self) -> str:
        """
        Returns the String representation of the current values of array.

        Returns
        - the String representation of the current values of array
        """
        ...



"""
Python module generated from Java source file com.google.gson.internal.bind.DateTypeAdapter

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import JsonSyntaxException
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.internal import JavaVersion
from com.google.gson.internal import PreJava9DateFormatProvider
from com.google.gson.internal.bind import *
from com.google.gson.internal.bind.util import ISO8601Utils
from com.google.gson.reflect import TypeToken
from com.google.gson.stream import JsonReader
from com.google.gson.stream import JsonToken
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.text import DateFormat
from java.text import ParseException
from java.text import ParsePosition
from java.util import Date
from java.util import Locale
from typing import Any, Callable, Iterable, Tuple


class DateTypeAdapter(TypeAdapter):
    """
    Adapter for Date. Although this class appears stateless, it is not.
    DateFormat captures its time zone and locale when it is created, which gives
    this class state. DateFormat isn't thread safe either, so this class has
    to synchronize its read and write methods.
    """

    FACTORY = TypeAdapterFactory() {
    
        // we use a runtime check to make sure the 'T's equal
        @SuppressWarnings("unchecked")
        @Override
        public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> typeToken) {
            return typeToken.getRawType() == Date.class ? (TypeAdapter<T>) DateTypeAdapter() : null;
        }
    }


    def __init__(self):
        ...


    def read(self, in: "JsonReader") -> "Date":
        ...


    def write(self, out: "JsonWriter", value: "Date") -> None:
        ...



"""
Python module generated from Java source file org.bukkit.block.Lockable

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class Lockable:
    """
    Represents a block (usually a container) that may be locked. When a lock is
    active an item with a name corresponding to the key will be required to open
    this block.
    """

    def isLocked(self) -> bool:
        """
        Checks if the container has a valid (non empty) key.

        Returns
        - True if the key is valid.
        """
        ...


    def getLock(self) -> str:
        """
        Gets the key needed to access the container.

        Returns
        - the key needed.
        """
        ...


    def setLock(self, key: str) -> None:
        """
        Sets the key required to access this container. Set to null (or empty
        string) to remove key.

        Arguments
        - key: the key required to access the container.
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.Snowable

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import *
from typing import Any, Callable, Iterable, Tuple


class Snowable(BlockData):
    """
    'snowy' denotes whether this block has a snow covered side and top texture
    (normally because the block above is snow).
    """

    def isSnowy(self) -> bool:
        """
        Gets the value of the 'snowy' property.

        Returns
        - the 'snowy' value
        """
        ...


    def setSnowy(self, snowy: bool) -> None:
        """
        Sets the value of the 'snowy' property.

        Arguments
        - snowy: the new 'snowy' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.components.FoodComponent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.configuration.serialization import ConfigurationSerializable
from org.bukkit.inventory import ItemStack
from org.bukkit.inventory.meta.components import *
from org.bukkit.potion import PotionEffect
from typing import Any, Callable, Iterable, Tuple


class FoodComponent(ConfigurationSerializable):
    """
    Represents a component which can turn any item into food.
    """

    def getNutrition(self) -> int:
        """
        Gets the food restored by this item when eaten.

        Returns
        - nutrition value
        """
        ...


    def setNutrition(self, nutrition: int) -> None:
        """
        Sets the food restored by this item when eaten.

        Arguments
        - nutrition: new nutrition value, must be non-negative
        """
        ...


    def getSaturation(self) -> float:
        """
        Gets the saturation restored by this item when eaten.

        Returns
        - saturation value
        """
        ...


    def setSaturation(self, saturation: float) -> None:
        """
        Sets the saturation restored by this item when eaten.

        Arguments
        - saturation: new saturation value
        """
        ...


    def canAlwaysEat(self) -> bool:
        """
        Gets if this item can be eaten even when not hungry.

        Returns
        - True if always edible
        """
        ...


    def setCanAlwaysEat(self, canAlwaysEat: bool) -> None:
        """
        Sets if this item can be eaten even when not hungry.

        Arguments
        - canAlwaysEat: whether always edible
        """
        ...


    def getEatSeconds(self) -> float:
        """
        Gets the time in seconds it will take for this item to be eaten.

        Returns
        - eat time
        """
        ...


    def setEatSeconds(self, eatSeconds: float) -> None:
        """
        Sets the time in seconds it will take for this item to be eaten.

        Arguments
        - eatSeconds: new eat time
        """
        ...


    def getUsingConvertsTo(self) -> "ItemStack":
        """
        Gets the item this food will convert to once eaten.

        Returns
        - converted item
        """
        ...


    def setUsingConvertsTo(self, item: "ItemStack") -> None:
        """
        Sets the item this food will convert to once eaten.

        Arguments
        - item: converted item
        """
        ...


    def getEffects(self) -> list["FoodEffect"]:
        """
        Gets the effects which may be applied by this item when eaten.

        Returns
        - food effects
        """
        ...


    def setEffects(self, effects: list["FoodEffect"]) -> None:
        """
        Sets the effects which may be applied by this item when eaten.

        Arguments
        - effects: new effects
        """
        ...


    def addEffect(self, effect: "PotionEffect", probability: float) -> "FoodEffect":
        """
        Adds an effect which may be applied by this item when eaten.

        Arguments
        - effect: the effect
        - probability: the probability of the effect being applied

        Returns
        - the added effect
        """
        ...


    class FoodEffect(ConfigurationSerializable):
        """
        An effect which may be applied by this item when eaten.
        """

        def getEffect(self) -> "PotionEffect":
            """
            Gets the effect which may be applied.

            Returns
            - the effect
            """
            ...


        def setEffect(self, effect: "PotionEffect") -> None:
            """
            Sets the effect which may be applied.

            Arguments
            - effect: the new effect
            """
            ...


        def getProbability(self) -> float:
            """
            Gets the probability of this effect being applied.

            Returns
            - probability
            """
            ...


        def setProbability(self, probability: float) -> None:
            """
            Sets the probability of this effect being applied.

            Arguments
            - probability: between 0 and 1 inclusive.
            """
            ...



"""
Python module generated from Java source file org.bukkit.event.inventory.PrepareAnvilEvent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event import HandlerList
from org.bukkit.event.inventory import *
from org.bukkit.inventory import AnvilInventory
from org.bukkit.inventory import ItemStack
from org.bukkit.inventory.view import AnvilView
from typing import Any, Callable, Iterable, Tuple


class PrepareAnvilEvent(PrepareInventoryResultEvent):
    """
    Called when an item is put in a slot for repair by an anvil.
    """

    def __init__(self, inventory: "AnvilView", result: "ItemStack"):
        ...


    def getInventory(self) -> "AnvilInventory":
        ...


    def getView(self) -> "AnvilView":
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.base.CommonMatcher

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from typing import Any, Callable, Iterable, Tuple


class CommonMatcher:
    """
    The subset of the java.util.regex.Matcher API which is used by this package, and also
    shared with the `re2j` library. For internal use only. Please refer to the `Matcher`
    javadoc for details.
    """

    def matches(self) -> bool:
        ...


    def find(self) -> bool:
        ...


    def find(self, index: int) -> bool:
        ...


    def replaceAll(self, replacement: str) -> str:
        ...


    def end(self) -> int:
        ...


    def start(self) -> int:
        ...



"""
Python module generated from Java source file org.bukkit.block.data.Hatchable

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import *
from typing import Any, Callable, Iterable, Tuple


class Hatchable(BlockData):
    """
    'hatch' is the number of entities which may hatch from these eggs.
    """

    def getHatch(self) -> int:
        """
        Gets the value of the 'hatch' property.

        Returns
        - the 'hatch' value
        """
        ...


    def setHatch(self, hatch: int) -> None:
        """
        Sets the value of the 'hatch' property.

        Arguments
        - hatch: the new 'hatch' value
        """
        ...


    def getMaximumHatch(self) -> int:
        """
        Gets the maximum allowed value of the 'hatch' property.

        Returns
        - the maximum 'hatch' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.SlimeSplitEvent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Slime
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class SlimeSplitEvent(EntityEvent, Cancellable):
    """
    Called when a Slime splits into smaller Slimes upon death
    """

    def __init__(self, slime: "Slime", count: int):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getEntity(self) -> "Slime":
        ...


    def getCount(self) -> int:
        """
        Gets the amount of smaller slimes to spawn

        Returns
        - the amount of slimes to spawn
        """
        ...


    def setCount(self, count: int) -> None:
        """
        Sets how many smaller slimes will spawn on the split

        Arguments
        - count: the amount of slimes to spawn
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.TechnicalPiston

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data import Directional
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class TechnicalPiston(Directional):
    """
    'type' represents the type of piston which this (technical) block corresponds
    to.
    """

    def getType(self) -> "Type":
        """
        Gets the value of the 'type' property.

        Returns
        - the 'type' value
        """
        ...


    def setType(self, type: "Type") -> None:
        """
        Sets the value of the 'type' property.

        Arguments
        - type: the new 'type' value
        """
        ...


    class Type(Enum):
        """
        Different piston variants.
        """

        NORMAL = 0
        """
        A normal piston which does not pull connected blocks backwards on
        retraction.
        """
        STICKY = 1
        """
        A sticky piston which will also retract connected blocks.
        """



"""
Python module generated from Java source file org.bukkit.util.noise.SimplexNoiseGenerator

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Random
from org.bukkit import World
from org.bukkit.util.noise import *
from typing import Any, Callable, Iterable, Tuple


class SimplexNoiseGenerator(PerlinNoiseGenerator):
    """
    Generates simplex-based noise.
    
    This is a modified version of the freely published version in the paper by
    Stefan Gustavson at
    <a href="http://staffwww.itn.liu.se/~stegu/simplexnoise/simplexnoise.pdf">
    http://staffwww.itn.liu.se/~stegu/simplexnoise/simplexnoise.pdf</a>
    """

    def __init__(self, world: "World"):
        """
        Creates a seeded simplex noise generator for the given world

        Arguments
        - world: World to construct this generator for
        """
        ...


    def __init__(self, seed: int):
        """
        Creates a seeded simplex noise generator for the given seed

        Arguments
        - seed: Seed to construct this generator for
        """
        ...


    def __init__(self, rand: "Random"):
        """
        Creates a seeded simplex noise generator with the given Random

        Arguments
        - rand: Random to construct with
        """
        ...


    @staticmethod
    def getNoise(xin: float) -> float:
        """
        Computes and returns the 1D unseeded simplex noise for the given
        coordinates in 1D space

        Arguments
        - xin: X coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    @staticmethod
    def getNoise(xin: float, yin: float) -> float:
        """
        Computes and returns the 2D unseeded simplex noise for the given
        coordinates in 2D space

        Arguments
        - xin: X coordinate
        - yin: Y coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    @staticmethod
    def getNoise(xin: float, yin: float, zin: float) -> float:
        """
        Computes and returns the 3D unseeded simplex noise for the given
        coordinates in 3D space

        Arguments
        - xin: X coordinate
        - yin: Y coordinate
        - zin: Z coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    @staticmethod
    def getNoise(x: float, y: float, z: float, w: float) -> float:
        """
        Computes and returns the 4D simplex noise for the given coordinates in
        4D space

        Arguments
        - x: X coordinate
        - y: Y coordinate
        - z: Z coordinate
        - w: W coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    def noise(self, xin: float, yin: float, zin: float) -> float:
        ...


    def noise(self, xin: float, yin: float) -> float:
        ...


    def noise(self, x: float, y: float, z: float, w: float) -> float:
        """
        Computes and returns the 4D simplex noise for the given coordinates in
        4D space

        Arguments
        - x: X coordinate
        - y: Y coordinate
        - z: Z coordinate
        - w: W coordinate

        Returns
        - Noise at given location, from range -1 to 1
        """
        ...


    @staticmethod
    def getInstance() -> "SimplexNoiseGenerator":
        """
        Gets the singleton unseeded instance of this generator

        Returns
        - Singleton
        """
        ...



"""
Python module generated from Java source file org.bukkit.conversations.ManuallyAbandonedConversationCanceller

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.conversations import *
from typing import Any, Callable, Iterable, Tuple


class ManuallyAbandonedConversationCanceller(ConversationCanceller):
    """
    The ManuallyAbandonedConversationCanceller is only used as part of a ConversationAbandonedEvent to indicate that the conversation was manually
    abandoned by programmatically calling the abandon() method on it.
    """

    def setConversation(self, conversation: "Conversation") -> None:
        ...


    def cancelBasedOnInput(self, context: "ConversationContext", input: str) -> bool:
        ...


    def clone(self) -> "ConversationCanceller":
        ...



"""
Python module generated from Java source file com.google.common.hash.Striped64

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.hash import *
from java.util import Random
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Striped64(Number):
    """
    A package-local class holding common representation and mechanics for classes supporting dynamic
    striping on 64bit values. The class extends Number so that concrete subclasses must publicly do
    so.
    """





"""
Python module generated from Java source file org.bukkit.event.entity.StriderTemperatureChangeEvent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Strider
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class StriderTemperatureChangeEvent(EntityEvent, Cancellable):
    """
    Called when a Strider's temperature has changed as a result of
    entering or exiting blocks it considers warm.
    """

    def __init__(self, what: "Strider", shivering: bool):
        ...


    def getEntity(self) -> "Strider":
        ...


    def isShivering(self) -> bool:
        """
        Get the Strider's new shivering state.

        Returns
        - the new shivering state
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancelled: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.Brushable

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import *
from typing import Any, Callable, Iterable, Tuple


class Brushable(BlockData):
    """
    'dusted' represents how far uncovered by brush the block is.
    """

    def getDusted(self) -> int:
        """
        Gets the value of the 'dusted' property.

        Returns
        - the 'dusted' value
        """
        ...


    def setDusted(self, dusted: int) -> None:
        """
        Sets the value of the 'dusted' property.

        Arguments
        - dusted: the new 'dusted' value
        """
        ...


    def getMaximumDusted(self) -> int:
        """
        Gets the maximum allowed value of the 'dusted' property.

        Returns
        - the maximum 'dusted' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.DecoratedPotInventory

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import DecoratedPot
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class DecoratedPotInventory(Inventory):
    """
    Interface to the inventory of a DecoratedPot.
    """

    def setItem(self, item: "ItemStack") -> None:
        """
        Set the item stack in the decorated pot.

        Arguments
        - item: the new item stack
        """
        ...


    def getItem(self) -> "ItemStack":
        """
        Get the item stack in the decorated pot.

        Returns
        - the current item stack
        """
        ...


    def getHolder(self) -> "DecoratedPot":
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerChannelEvent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerChannelEvent(PlayerEvent):
    """
    This event is called after a player registers or unregisters a new plugin
    channel.
    """

    def __init__(self, player: "Player", channel: str):
        ...


    def getChannel(self) -> str:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.gson.annotations.JsonAdapter

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import Gson
from com.google.gson import JsonDeserializer
from com.google.gson import JsonSerializer
from com.google.gson import TypeAdapter
from com.google.gson import TypeAdapterFactory
from com.google.gson.annotations import *
from typing import Any, Callable, Iterable, Tuple


class JsonAdapter:

    def value(self) -> type[Any]:
        """
        Either a TypeAdapter or TypeAdapterFactory, or one or both of JsonDeserializer or JsonSerializer.
        """
        ...


    def nullSafe(self) -> bool:
        """
        False, to be able to handle `null` values within the adapter, default value is True.
        """
        return True



"""
Python module generated from Java source file org.bukkit.block.data.type.Hopper

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Directional
from org.bukkit.block.data import Powerable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Hopper(Directional):
    """
    Similar to Powerable, 'enabled' indicates whether or not the hopper
    is currently activated.
    
    Unlike most other blocks, a hopper is only enabled when it is **not**
    receiving any power.
    """

    def isEnabled(self) -> bool:
        """
        Gets the value of the 'enabled' property.

        Returns
        - the 'enabled' value
        """
        ...


    def setEnabled(self, enabled: bool) -> None:
        """
        Sets the value of the 'enabled' property.

        Arguments
        - enabled: the new 'enabled' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Lectern

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Directional
from org.bukkit.block.data import Powerable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Lectern(Directional, Powerable):
    """
    'has_book' is a quick flag to check whether this lectern has a book inside
    it.
    """

    def hasBook(self) -> bool:
        """
        Gets the value of the 'has_book' property.

        Returns
        - the 'has_book' value
        """
        ...



"""
Python module generated from Java source file com.google.gson.stream.JsonReader

Java source file obtained from artifact gson version 2.10.1

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import JsonReaderInternalAccess
from com.google.gson.internal.bind import JsonTreeReader
from com.google.gson.stream import *
from java.io import Closeable
from java.io import EOFException
from java.io import IOException
from java.io import Reader
from java.util import Arrays
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class JsonReader(Closeable):
    """
    Reads a JSON (<a href="http://www.ietf.org/rfc/rfc7159.txt">RFC 7159</a>)
    encoded value as a stream of tokens. This stream includes both literal
    values (strings, numbers, booleans, and nulls) as well as the begin and
    end delimiters of objects and arrays. The tokens are traversed in
    depth-first order, the same order that they appear in the JSON document.
    Within JSON objects, name/value pairs are represented by a single token.
    
    <h2>Parsing JSON</h2>
    To create a recursive descent parser for your own JSON streams, first create
    an entry point method that creates a `JsonReader`.
    
    Next, create handler methods for each structure in your JSON text. You'll
    need a method for each object type and for each array type.
    
      - Within <strong>array handling</strong> methods, first call .beginArray to consume the array's opening bracket. Then create a
          while loop that accumulates values, terminating when .hasNext
          is False. Finally, read the array's closing bracket by calling .endArray.
      - Within <strong>object handling</strong> methods, first call .beginObject to consume the object's opening brace. Then create a
          while loop that assigns values to local variables based on their name.
          This loop should terminate when .hasNext is False. Finally,
          read the object's closing brace by calling .endObject.
    
    When a nested object or array is encountered, delegate to the
    corresponding handler method.
    
    When an unknown name is encountered, strict parsers should fail with an
    exception. Lenient parsers should call .skipValue() to recursively
    skip the value's nested tokens, which may otherwise conflict.
    
    If a value may be null, you should first check using .peek().
    Null literals can be consumed using either .nextNull() or .skipValue().
    
    <h2>Example</h2>
    Suppose we'd like to parse a stream of messages such as the following: ``` `[
      {
        "id": 912345678901,
        "text": "How do I read a JSON stream in Java?",
        "geo": null,
        "user": {
          "name": "json_newb",
          "followers_count": 41`
      },
      {
        "id": 912345678902,
        "text": "@json_newb just use JsonReader!",
        "geo": [50.454722, -104.606667],
        "user": {
          "name": "jesse",
          "followers_count": 2
        }
      }
    ]}```
    This code implements the parser for the above structure: ```   `public List<Message> readJsonStream(InputStream in) throws IOException {
        JsonReader reader = new JsonReader(new InputStreamReader(in, "UTF-8"));
        try {
          return readMessagesArray(reader);` finally {
          reader.close();
        }
      }
    
      public List<Message> readMessagesArray(JsonReader reader) throws IOException {
        List<Message> messages = new ArrayList<>();
    
        reader.beginArray();
        while (reader.hasNext()) {
          messages.add(readMessage(reader));
        }
        reader.endArray();
        return messages;
      }
    
      public Message readMessage(JsonReader reader) throws IOException {
        long id = -1;
        String text = null;
        User user = null;
        List<Double> geo = null;
    
        reader.beginObject();
        while (reader.hasNext()) {
          String name = reader.nextName();
          if (name.equals("id")) {
            id = reader.nextLong();
          } else if (name.equals("text")) {
            text = reader.nextString();
          } else if (name.equals("geo") && reader.peek() != JsonToken.NULL) {
            geo = readDoublesArray(reader);
          } else if (name.equals("user")) {
            user = readUser(reader);
          } else {
            reader.skipValue();
          }
        }
        reader.endObject();
        return new Message(id, text, user, geo);
      }
    
      public List<Double> readDoublesArray(JsonReader reader) throws IOException {
        List<Double> doubles = new ArrayList<>();
    
        reader.beginArray();
        while (reader.hasNext()) {
          doubles.add(reader.nextDouble());
        }
        reader.endArray();
        return doubles;
      }
    
      public User readUser(JsonReader reader) throws IOException {
        String username = null;
        int followersCount = -1;
    
        reader.beginObject();
        while (reader.hasNext()) {
          String name = reader.nextName();
          if (name.equals("name")) {
            username = reader.nextString();
          } else if (name.equals("followers_count")) {
            followersCount = reader.nextInt();
          } else {
            reader.skipValue();
          }
        }
        reader.endObject();
        return new User(username, followersCount);
      }}```
    
    <h2>Number Handling</h2>
    This reader permits numeric values to be read as strings and string values to
    be read as numbers. For example, both elements of the JSON array `[1, "1"]` may be read using either .nextInt or .nextString.
    This behavior is intended to prevent lossy numeric conversions: double is
    JavaScript's only numeric type and very large values like `9007199254740993` cannot be represented exactly on that platform. To minimize
    precision loss, extremely large values should be written and read as strings
    in JSON.
    
    <h2 id="nonexecuteprefix">Non-Execute Prefix</h2>
    Web servers that serve private data using JSON may be vulnerable to <a
    href="http://en.wikipedia.org/wiki/JSON#Cross-site_request_forgery">Cross-site
    request forgery</a> attacks. In such an attack, a malicious site gains access
    to a private JSON file by executing it with an HTML `<script>` tag.
    
    Prefixing JSON files with `")]}'\n"` makes them non-executable
    by `<script>` tags, disarming the attack. Since the prefix is malformed
    JSON, strict parsing fails when it is encountered. This class permits the
    non-execute prefix when .setLenient(boolean) lenient parsing is
    enabled.
    
    Each `JsonReader` may be used to read a single JSON stream. Instances
    of this class are not thread safe.

    Author(s)
    - Jesse Wilson

    Since
    - 1.6
    """

    def __init__(self, in: "Reader"):
        """
        Creates a new instance that reads a JSON-encoded stream from `in`.
        """
        ...


    def setLenient(self, lenient: bool) -> None:
        """
        Configure this parser to be liberal in what it accepts. By default,
        this parser is strict and only accepts JSON as specified by <a
        href="http://www.ietf.org/rfc/rfc4627.txt">RFC 4627</a>. Setting the
        parser to lenient causes it to ignore the following syntax errors:
        
        
          - Streams that start with the <a href="#nonexecuteprefix">non-execute
              prefix</a>, `")]}'\n"`.
          - Streams that include multiple top-level values. With strict parsing,
              each stream must contain exactly one top-level value.
          - Numbers may be Double.isNaN() NaNs or Double.isInfinite() infinities.
          - End of line comments starting with `//` or `.` and
              ending with a newline character.
          - C-style comments starting with `/*` and ending with
              `*``/`. Such comments may not be nested.
          - Names that are unquoted or `'single quoted'`.
          - Strings that are unquoted or `'single quoted'`.
          - Array elements separated by `;` instead of `,`.
          - Unnecessary array separators. These are interpreted as if null
              was the omitted value.
          - Names and values separated by `=` or `=>` instead of
              `:`.
          - Name/value pairs separated by `;` instead of `,`.
        
        
        Note: Even in strict mode there are slight derivations from the JSON
        specification:
        
          - JsonReader allows the literals `True`, `False` and `null`
              to have any capitalization, for example `fAlSe`
          - JsonReader supports the escape sequence `\'`, representing a `'`
          - JsonReader supports the escape sequence `\*LF*` (with `LF`
              being the Unicode character U+000A), resulting in a `LF` within the
              read JSON string
          - JsonReader allows unescaped control characters (U+0000 through U+001F)
        """
        ...


    def isLenient(self) -> bool:
        """
        Returns True if this parser is liberal in what it accepts.
        """
        ...


    def beginArray(self) -> None:
        """
        Consumes the next token from the JSON stream and asserts that it is the
        beginning of a new array.
        """
        ...


    def endArray(self) -> None:
        """
        Consumes the next token from the JSON stream and asserts that it is the
        end of the current array.
        """
        ...


    def beginObject(self) -> None:
        """
        Consumes the next token from the JSON stream and asserts that it is the
        beginning of a new object.
        """
        ...


    def endObject(self) -> None:
        """
        Consumes the next token from the JSON stream and asserts that it is the
        end of the current object.
        """
        ...


    def hasNext(self) -> bool:
        """
        Returns True if the current array or object has another element.
        """
        ...


    def peek(self) -> "JsonToken":
        """
        Returns the type of the next token without consuming it.
        """
        ...


    def nextName(self) -> str:
        """
        Returns the next token, a JsonToken.NAME property name, and consumes it.

        Raises
        - IOException: if the next token in the stream is not a property
            name.
        """
        ...


    def nextString(self) -> str:
        """
        Returns the JsonToken.STRING string value of the next token,
        consuming it. If the next token is a number, this method will return its
        string form.

        Raises
        - IllegalStateException: if the next token is not a string or if
            this reader is closed.
        """
        ...


    def nextBoolean(self) -> bool:
        """
        Returns the JsonToken.BOOLEAN boolean value of the next token,
        consuming it.

        Raises
        - IllegalStateException: if the next token is not a boolean or if
            this reader is closed.
        """
        ...


    def nextNull(self) -> None:
        """
        Consumes the next token from the JSON stream and asserts that it is a
        literal null.

        Raises
        - IllegalStateException: if the next token is not null or if this
            reader is closed.
        """
        ...


    def nextDouble(self) -> float:
        """
        Returns the JsonToken.NUMBER double value of the next token,
        consuming it. If the next token is a string, this method will attempt to
        parse it as a double using Double.parseDouble(String).

        Raises
        - IllegalStateException: if the next token is not a literal value.
        - NumberFormatException: if the next literal value cannot be parsed
            as a double.
        - MalformedJsonException: if the next literal value is NaN or Infinity
            and this reader is not .setLenient(boolean) lenient.
        """
        ...


    def nextLong(self) -> int:
        """
        Returns the JsonToken.NUMBER long value of the next token,
        consuming it. If the next token is a string, this method will attempt to
        parse it as a long. If the next token's numeric value cannot be exactly
        represented by a Java `long`, this method throws.

        Raises
        - IllegalStateException: if the next token is not a literal value.
        - NumberFormatException: if the next literal value cannot be parsed
            as a number, or exactly represented as a long.
        """
        ...


    def nextInt(self) -> int:
        """
        Returns the JsonToken.NUMBER int value of the next token,
        consuming it. If the next token is a string, this method will attempt to
        parse it as an int. If the next token's numeric value cannot be exactly
        represented by a Java `int`, this method throws.

        Raises
        - IllegalStateException: if the next token is not a literal value.
        - NumberFormatException: if the next literal value cannot be parsed
            as a number, or exactly represented as an int.
        """
        ...


    def close(self) -> None:
        """
        Closes this JSON reader and the underlying Reader.
        """
        ...


    def skipValue(self) -> None:
        """
        Skips the next value recursively. This method is intended for use when
        the JSON token stream contains unrecognized or unhandled values.
        
        The behavior depends on the type of the next JSON token:
        
          - Start of a JSON array or object: It and all of its nested values are skipped.
          - Primitive value (for example a JSON number): The primitive value is skipped.
          - Property name: Only the name but not the value of the property is skipped.
          `skipValue()` has to be called again to skip the property value as well.
          - End of a JSON array or object: Only this end token is skipped.
          - End of JSON document: Skipping has no effect, the next token continues to be the
          end of the document.
        """
        ...


    def toString(self) -> str:
        ...


    def getPreviousPath(self) -> str:
        """
        Returns a <a href="https://goessner.net/articles/JsonPath/">JSONPath</a>
        in *dot-notation* to the previous (or current) location in the JSON document:
        
          - For JSON arrays the path points to the index of the previous element.
          If no element has been consumed yet it uses the index 0 (even if there are no elements).
          - For JSON objects the path points to the last property, or to the current
          property if its name has already been consumed.
        
        
        This method can be useful to add additional context to exception messages
        *after* a value has been consumed.
        """
        ...


    def getPath(self) -> str:
        """
        Returns a <a href="https://goessner.net/articles/JsonPath/">JSONPath</a>
        in *dot-notation* to the next (or current) location in the JSON document:
        
          - For JSON arrays the path points to the index of the next element (even
          if there are no further elements).
          - For JSON objects the path points to the last property, or to the current
          property if its name has already been consumed.
        
        
        This method can be useful to add additional context to exception messages
        *before* a value is consumed, for example when the .peek() peeked
        token is unexpected.
        """
        ...



from .StratifiedSampling import StratifiedSampling
from .SpiralSampling import SpiralSampling
from .UniformSampling import UniformSampling
from .BestCandidateSampling import BestCandidateSampling
from .Callback3d import Callback3d
from .Callback2d import Callback2d
from .PoissonSampling import PoissonSampling
from .Convolution import Convolution
from .Math import Math


"""
Python module generated from Java source file org.bukkit.event.raid.RaidTriggerEvent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Raid
from org.bukkit import World
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.raid import *
from typing import Any, Callable, Iterable, Tuple


class RaidTriggerEvent(RaidEvent, Cancellable):
    """
    Called when a Raid is triggered (e.g: a player with Bad Omen effect
    enters a village).
    """

    def __init__(self, raid: "Raid", world: "World", player: "Player"):
        ...


    def getPlayer(self) -> "Player":
        """
        Returns the player who triggered the raid.

        Returns
        - triggering player
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.plugin.InvalidDescriptionException

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class InvalidDescriptionException(Exception):
    """
    Thrown when attempting to load an invalid PluginDescriptionFile
    """

    def __init__(self, cause: "Throwable", message: str):
        """
        Constructs a new InvalidDescriptionException based on the given
        Exception

        Arguments
        - message: Brief message explaining the cause of the exception
        - cause: Exception that triggered this Exception
        """
        ...


    def __init__(self, cause: "Throwable"):
        """
        Constructs a new InvalidDescriptionException based on the given
        Exception

        Arguments
        - cause: Exception that triggered this Exception
        """
        ...


    def __init__(self, message: str):
        """
        Constructs a new InvalidDescriptionException with the given message

        Arguments
        - message: Brief message explaining the cause of the exception
        """
        ...


    def __init__(self):
        """
        Constructs a new InvalidDescriptionException
        """
        ...



"""
Python module generated from Java source file org.bukkit.attribute.Attribute

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import Bukkit
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit import Translatable
from org.bukkit.attribute import *
from typing import Any, Callable, Iterable, Tuple


class Attribute(Enum):
    """
    Types of attributes which may be present on an Attributable.
    """

    GENERIC_MAX_HEALTH = ("generic.max_health")
    """
    Maximum health of an Entity.
    """
    GENERIC_FOLLOW_RANGE = ("generic.follow_range")
    """
    Range at which an Entity will follow others.
    """
    GENERIC_KNOCKBACK_RESISTANCE = ("generic.knockback_resistance")
    """
    Resistance of an Entity to knockback.
    """
    GENERIC_MOVEMENT_SPEED = ("generic.movement_speed")
    """
    Movement speed of an Entity.
    """
    GENERIC_FLYING_SPEED = ("generic.flying_speed")
    """
    Flying speed of an Entity.
    """
    GENERIC_ATTACK_DAMAGE = ("generic.attack_damage")
    """
    Attack damage of an Entity.
    """
    GENERIC_ATTACK_KNOCKBACK = ("generic.attack_knockback")
    """
    Attack knockback of an Entity.
    """
    GENERIC_ATTACK_SPEED = ("generic.attack_speed")
    """
    Attack speed of an Entity.
    """
    GENERIC_ARMOR = ("generic.armor")
    """
    Armor bonus of an Entity.
    """
    GENERIC_ARMOR_TOUGHNESS = ("generic.armor_toughness")
    """
    Armor durability bonus of an Entity.
    """
    GENERIC_FALL_DAMAGE_MULTIPLIER = ("generic.fall_damage_multiplier")
    """
    The fall damage multiplier of an Entity.
    """
    GENERIC_LUCK = ("generic.luck")
    """
    Luck bonus of an Entity.
    """
    GENERIC_MAX_ABSORPTION = ("generic.max_absorption")
    """
    Maximum absorption of an Entity.
    """
    GENERIC_SAFE_FALL_DISTANCE = ("generic.safe_fall_distance")
    """
    The distance which an Entity can fall without damage.
    """
    GENERIC_SCALE = ("generic.scale")
    """
    The relative scale of an Entity.
    """
    GENERIC_STEP_HEIGHT = ("generic.step_height")
    """
    The height which an Entity can walk over.
    """
    GENERIC_GRAVITY = ("generic.gravity")
    """
    The gravity applied to an Entity.
    """
    GENERIC_JUMP_STRENGTH = ("generic.jump_strength")
    """
    Strength with which an Entity will jump.
    """
    GENERIC_BURNING_TIME = ("generic.burning_time")
    """
    How long an entity remains burning after ingition.
    """
    GENERIC_EXPLOSION_KNOCKBACK_RESISTANCE = ("generic.explosion_knockback_resistance")
    """
    Resistance to knockback from explosions.
    """
    GENERIC_MOVEMENT_EFFICIENCY = ("generic.movement_efficiency")
    """
    Movement speed through difficult terrain.
    """
    GENERIC_OXYGEN_BONUS = ("generic.oxygen_bonus")
    """
    Oxygen use underwater.
    """
    GENERIC_WATER_MOVEMENT_EFFICIENCY = ("generic.water_movement_efficiency")
    """
    Movement speed through water.
    """
    PLAYER_BLOCK_INTERACTION_RANGE = ("player.block_interaction_range")
    """
    The block reach distance of a Player.
    """
    PLAYER_ENTITY_INTERACTION_RANGE = ("player.entity_interaction_range")
    """
    The entity reach distance of a Player.
    """
    PLAYER_BLOCK_BREAK_SPEED = ("player.block_break_speed")
    """
    Block break speed of a Player.
    """
    PLAYER_MINING_EFFICIENCY = ("player.mining_efficiency")
    """
    Mining speed for correct tools.
    """
    PLAYER_SNEAKING_SPEED = ("player.sneaking_speed")
    """
    Sneaking speed.
    """
    PLAYER_SUBMERGED_MINING_SPEED = ("player.submerged_mining_speed")
    """
    Underwater mining speed.
    """
    PLAYER_SWEEPING_DAMAGE_RATIO = ("player.sweeping_damage_ratio")
    """
    Sweeping damage.
    """
    ZOMBIE_SPAWN_REINFORCEMENTS = ("zombie.spawn_reinforcements")
    """
    Chance of a zombie to spawn reinforcements.
    """


    def getKey(self) -> "NamespacedKey":
        ...


    def getTranslationKey(self) -> str:
        ...



"""
Python module generated from Java source file com.google.common.math.DoubleUtils

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.math import *
from java.math import BigInteger
from typing import Any, Callable, Iterable, Tuple


class DoubleUtils:
    """
    Utilities for `double` primitives.

    Author(s)
    - Louis Wasserman
    """





"""
Python module generated from Java source file com.google.common.collect.ReverseNaturalOrdering

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.io import Serializable
from java.util import Iterator
from typing import Any, Callable, Iterable, Tuple


class ReverseNaturalOrdering(Ordering, Serializable):
    """
    An ordering that uses the reverse of the natural order of the values.
    """

    def compare(self, left: "Comparable"[Any], right: "Comparable"[Any]) -> int:
        ...


    def reverse(self) -> "Ordering"["S"]:
        ...


    def min(self, a: "E", b: "E") -> "E":
        ...


    def min(self, a: "E", b: "E", c: "E", *rest: Tuple["E", ...]) -> "E":
        ...


    def min(self, iterator: Iterator["E"]) -> "E":
        ...


    def min(self, iterable: Iterable["E"]) -> "E":
        ...


    def max(self, a: "E", b: "E") -> "E":
        ...


    def max(self, a: "E", b: "E", c: "E", *rest: Tuple["E", ...]) -> "E":
        ...


    def max(self, iterator: Iterator["E"]) -> "E":
        ...


    def max(self, iterable: Iterable["E"]) -> "E":
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.event.vehicle.VehicleExitEvent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import LivingEntity
from org.bukkit.entity import Vehicle
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.vehicle import *
from typing import Any, Callable, Iterable, Tuple


class VehicleExitEvent(VehicleEvent, Cancellable):
    """
    Raised when a living entity exits a vehicle.
    """

    def __init__(self, vehicle: "Vehicle", exited: "LivingEntity"):
        ...


    def getExited(self) -> "LivingEntity":
        """
        Get the living entity that exited the vehicle.

        Returns
        - The entity.
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.material.PistonBaseMaterial

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class PistonBaseMaterial(MaterialData, Directional, Redstone):
    """
    Material data for the piston base block

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Constructs a PistonBaseMaterial.

        Arguments
        - type: the material type to use
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def setFacingDirection(self, face: "BlockFace") -> None:
        ...


    def getFacing(self) -> "BlockFace":
        ...


    def isPowered(self) -> bool:
        ...


    def setPowered(self, powered: bool) -> None:
        """
        Sets the current state of this piston

        Arguments
        - powered: True if the piston is extended & powered, or False
        """
        ...


    def isSticky(self) -> bool:
        """
        Checks if this piston base is sticky, and returns True if so

        Returns
        - True if this piston is "sticky", or False
        """
        ...


    def clone(self) -> "PistonBaseMaterial":
        ...



"""
Python module generated from Java source file org.bukkit.event.block.BlockPistonRetractEvent

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.block import Block
from org.bukkit.block import BlockFace
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockPistonRetractEvent(BlockPistonEvent):
    """
    Called when a piston retracts
    """

    def __init__(self, block: "Block", blocks: list["Block"], direction: "BlockFace"):
        ...


    def getRetractLocation(self) -> "Location":
        """
        Gets the location where the possible moving block might be if the
        retracting piston is sticky.

        Returns
        - The possible location of the possibly moving block.
        """
        ...


    def getBlocks(self) -> list["Block"]:
        """
        Get an immutable list of the blocks which will be moved by the
        extending.

        Returns
        - Immutable list of the moved blocks.
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.Art

Java source file obtained from artifact spigot-api version 1.21-R0.1-20240807.214924-87

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import Maps
from enum import Enum
from java.util import Locale
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class Art(Enum):
    """
    Represents the art on a painting
    """

    KEBAB = (0, 1, 1)
    AZTEC = (1, 1, 1)
    ALBAN = (2, 1, 1)
    AZTEC2 = (3, 1, 1)
    BOMB = (4, 1, 1)
    PLANT = (5, 1, 1)
    WASTELAND = (6, 1, 1)
    POOL = (7, 2, 1)
    COURBET = (8, 2, 1)
    SEA = (9, 2, 1)
    SUNSET = (10, 2, 1)
    CREEBET = (11, 2, 1)
    WANDERER = (12, 1, 2)
    GRAHAM = (13, 1, 2)
    MATCH = (14, 2, 2)
    BUST = (15, 2, 2)
    STAGE = (16, 2, 2)
    VOID = (17, 2, 2)
    SKULL_AND_ROSES = (18, 2, 2)
    WITHER = (19, 2, 2)
    FIGHTERS = (20, 4, 2)
    POINTER = (21, 4, 4)
    PIGSCENE = (22, 4, 4)
    BURNING_SKULL = (23, 4, 4)
    SKELETON = (24, 4, 3)
    DONKEY_KONG = (25, 4, 3)
    EARTH = (26, 2, 2)
    WIND = (27, 2, 2)
    WATER = (28, 2, 2)
    FIRE = (29, 2, 2)
    BAROQUE = (30, 2, 2)
    HUMBLE = (31, 2, 2)
    MEDITATIVE = (32, 1, 1)
    PRAIRIE_RIDE = (33, 1, 2)
    UNPACKED = (34, 4, 4)
    BACKYARD = (35, 3, 4)
    BOUQUET = (36, 3, 3)
    CAVEBIRD = (37, 3, 3)
    CHANGING = (38, 4, 2)
    COTAN = (39, 3, 3)
    ENDBOSS = (40, 3, 3)
    FERN = (41, 3, 3)
    FINDING = (42, 4, 2)
    LOWMIST = (43, 4, 2)
    ORB = (44, 4, 4)
    OWLEMONS = (45, 3, 3)
    PASSAGE = (46, 4, 2)
    POND = (47, 3, 4)
    SUNFLOWERS = (48, 3, 3)
    TIDES = (49, 3, 3)


    def getBlockWidth(self) -> int:
        """
        Gets the width of the painting, in blocks

        Returns
        - The width of the painting, in blocks
        """
        ...


    def getBlockHeight(self) -> int:
        """
        Gets the height of the painting, in blocks

        Returns
        - The height of the painting, in blocks
        """
        ...


    def getId(self) -> int:
        """
        Get the ID of this painting.

        Returns
        - The ID of this painting

        Deprecated
        - Magic value
        """
        ...


    def getKey(self) -> "NamespacedKey":
        ...


    @staticmethod
    def getById(id: int) -> "Art":
        """
        Get a painting by its numeric ID

        Arguments
        - id: The ID

        Returns
        - The painting

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def getByName(name: str) -> "Art":
        """
        Get a painting by its unique name
        
        This ignores underscores and capitalization

        Arguments
        - name: The name

        Returns
        - The painting
        """
        ...
